#[non_exhaustive]
pub enum Event { Locked, Finished, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Locked

session successfully locked

This client is now responsible for displaying graphics while the session is locked and deciding when to unlock the session.

The locked event must not be sent until a new “locked” frame has been presented on all outputs and no security sensitive normal/unlocked content is possibly visible.

If this event is sent, making the destroy request is a protocol error, the lock object must be destroyed using the unlock_and_destroy request.



Finished

the session lock object should be destroyed

The compositor has decided that the session lock should be destroyed as it will no longer be used by the compositor. Exactly when this event is sent is compositor policy, but it must never be sent more than once for a given session lock object.

This might be sent because there is already another ext_session_lock_v1 object held by a client, or the compositor has decided to deny the request to lock the session for some other reason. This might also be sent because the compositor implements some alternative, secure way to authenticate and unlock the session.

The finished event should be sent immediately on creation of this object if the compositor decides that the locked event will not be sent.

If the locked event is sent on creation of this object the finished event may still be sent at some later time in this object’s lifetime. This is compositor policy.

Upon receiving this event, the client should make either the destroy request or the unlock_and_destroy request, depending on whether or not the locked event was received on this object.

Implementations



impl Event

pub fn opcode(&self) -> u16

Get the opcode number of this message