#[non_exhaustive]
pub enum Request<'a> { Destroy, GetLockSurface { surface: WlSurface, output: WlOutput, }, UnlockAndDestroy, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy the session lock

This informs the compositor that the lock object will no longer be used. Existing objects created through this interface remain valid.

After this request is made, lock surfaces created through this object should be destroyed by the client as they will no longer be used by the compositor.

It is a protocol error to make this request if the locked event was sent, the unlock_and_destroy request must be used instead.

This is a destructor, once sent this object cannot be used any longer.



GetLockSurface

create a lock surface for a given output

The client is expected to create lock surfaces for all outputs currently present and any new outputs as they are advertised. These won’t be displayed by the compositor unless the lock is successful and the locked event is sent.

Providing a wl_surface which already has a role or already has a buffer attached or committed is a protocol error, as is attaching/committing a buffer before the first ext_session_lock_surface_v1.configure event.

Attempting to create more than one lock surface for a given output is a duplicate_output protocol error.

Fields

surface: WlSurface
output: WlOutput


UnlockAndDestroy

unlock the session, destroying the object

This request indicates that the session should be unlocked, for example because the user has entered their password and it has been verified by the client.

This request also informs the compositor that the lock object will no longer be used and should be destroyed. Existing objects created through this interface remain valid.

After this request is made, lock surfaces created through this object should be destroyed by the client as they will no longer be used by the compositor.

It is a protocol error to make this request if the locked event has not been sent. In that case, the lock object must be destroyed using the destroy request.

Note that a correct client that wishes to exit directly after unlocking the session must use the wl_display.sync request to ensure the server receives and processes the unlock_and_destroy request. Otherwise there is no guarantee that the server has unlocked the session due to the asynchronous nature of the Wayland protocol. For example, the server might terminate the client with a protocol error before it processes the unlock_and_destroy request.

This is a destructor, once sent this object cannot be used any longer.

Implementations



impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message